package com.gic.store.web.controller;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.response.EnterpriseRestResponse;
import com.gic.store.dto.StoreRegionDTO;
import com.gic.store.dto.StoreStatusSettingDTO;
import com.gic.store.service.StoreRegionApiService;
import com.gic.store.service.StoreStatusSettingApiService;
import com.gic.store.web.vo.StoreStatusSettingVO;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@RestController
public class StoreStatusSettingController {
    private Logger logger = Logger.getLogger(StoreStatusSettingController.class);

    @Autowired
    private StoreStatusSettingApiService storeStatusSettingApiService;
    @Autowired
    private StoreRegionApiService storeRegionApiService;

    @RequestMapping("storestatus-setting")
    public RestResponse saveStoreStatusSetting(Integer regionId, Integer days, Integer value, Integer storeStatusId){
        Integer enterpriseId = 1111;
        if(regionId == null || days == null || value == null){
            return EnterpriseRestResponse.failure(ErrorCode.ERR_2);
        }
        StoreStatusSettingDTO dto = new StoreStatusSettingDTO();
        dto.setEnterpriseId(enterpriseId);
        dto.setDays(days);
        dto.setRegionId(regionId);
        dto.setValue(value);
        dto.setStoreStatusId(storeStatusId);
        ServiceResponse serviceResponse = this.storeStatusSettingApiService.saveSetting(dto);
        if(serviceResponse.isSuccess()){
            return EnterpriseRestResponse.success(serviceResponse.getResult());
        }
        return EnterpriseRestResponse.failure(serviceResponse);
    }

    @RequestMapping("list-storestatus-setting")
    public RestResponse listStoreStatusSetting(){
        Integer enterpriseId = 1111;
        ServiceResponse<List<StoreStatusSettingDTO>> serviceResponse = this.storeStatusSettingApiService.listSetting(enterpriseId);
        if(serviceResponse.isSuccess()){
            List<StoreStatusSettingVO> list = new ArrayList<>();
            for(StoreStatusSettingDTO dto : serviceResponse.getResult()){
                StoreStatusSettingVO vo = new StoreStatusSettingVO();
                vo.setDays(dto.getDays());
                vo.setEnterpriseId(enterpriseId);
                vo.setRegionId(dto.getRegionId());
                ServiceResponse<StoreRegionDTO> response = this.storeRegionApiService.getStoreRegionByRegion(enterpriseId, dto.getRegionId());
                if(response.isSuccess()){
                    vo.setRegionName(response.getResult().getRegionName());
                }
                vo.setStoreStatusId(dto.getStoreStatusId());
                vo.setValue(dto.getValue());
                list.add(vo);
            }
            return RestResponse.success(list);
        }
        return EnterpriseRestResponse.failure(serviceResponse);
    }

    @RequestMapping("delete-storestatus-setting")
    public RestResponse deleteStoreStatusSetting(Integer id){
        if(id == null){
            return EnterpriseRestResponse.failure(ErrorCode.ERR_2);
        }
        Integer enterpriseId = 1111;
        ServiceResponse serviceResponse = this.storeStatusSettingApiService.delete(enterpriseId, id);
        if(serviceResponse.isSuccess()){
            return RestResponse.success();
        }
        return EnterpriseRestResponse.failure(serviceResponse);
    }
}
